==> react-google-map-components-0.0.23.tgz: package/es/data-polygon/DataPolygon.js <==
import _isEqual from "lodash-es/isEqual";
import _pick from "lodash-es/pick";

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";

import PropTypes from "prop-types";
import { createListeners } from "../internal/Utils";
import { MapContext } from "../internal/MapContext";
import DataLayerEvents from "../data-layer/DataLayerEvents";

var pickStyles = function pickStyles(x) {
  return _pick(x, ["clickable", "fillColor", "fillOpacity", "strokeColor", "strokeOpacity", "strokeWeight", "zIndex"]);
};

/**
 * Draws `google.maps.Data.Polygon`.
 *
 * **Usage:**
 *
 * ```javascript
 * import React from "react";
 * import { GoogleMap, DataPolygon } from "react-google-map-components"
 *
 * export default function GoogleMapWrapper(props) {
 *   return (
 *     <GoogleMap {...props} maps={google.maps}>
 *       <DataPolygon geometry={props.polygon} />
 *     </GoogleMap>
 *   );
 * }
 * ```
 *
 * **Google Maps Docs:**
 * * [google.maps.Data.Polygon](https://developers.google.com/maps/documentation/javascript/reference#Data.Polygon)
 */
export var DataPolygon = function (_React$Component) {
  _inherits(DataPolygon, _React$Component);

  function DataPolygon() {
    _classCallCheck(this, DataPolygon);

    return _possibleConstructorReturn(this, (DataPolygon.__proto__ || Object.getPrototypeOf(DataPolygon)).apply(this, arguments));
  }

  _createClass(DataPolygon, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      var _this2 = this;

      var mapContext = this.context.mapContext;


      this.listeners = [];
      this.feature = new mapContext.maps.Data.Feature();

      this.updateStyles();
      this.updateGeometry();

      mapContext.map.data.add(this.feature);

      createListeners(DataLayerEvents, function (x) {
        return _this2.props[x];
      }).forEach(function (_ref) {
        var _ref2 = _slicedToArray(_ref, 2),
            event = _ref2[0],
            listener = _ref2[1];

        _this2.addListener(event, listener);
      });
    }
  }, {
    key: "componentWillUpdate",
    value: function componentWillUpdate(nextProps) {
      this.updateStyles(nextProps);

      if (!_isEqual(nextProps.geometry, this.props.geometry)) {
        this.updateGeometry(nextProps);
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.context.mapContext.map.data.remove(this.feature);

      while (this.listeners.length > 0) {
        this.listeners.shift().remove();
      }
    }
  }, {
    key: "addListener",
    value: function addListener(event, listener) {
      var _this3 = this;

      this.listeners.push(this.context.mapContext.map.data.addListener(event, function (x) {
        if (x.feature === _this3.feature) {
          listener(x);
        }
      }));
    }
  }, {
    key: "updateStyles",
    value: function updateStyles() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;

      var styles = pickStyles(props);

      this.context.mapContext.map.data.overrideStyle(this.feature, styles);
    }
  }, {
    key: "updateGeometry",
    value: function updateGeometry() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;

      this.feature.setGeometry(new this.context.mapContext.maps.Data.Polygon(props.geometry));
    }
  }, {
    key: "render",
    value: function render() {
      return null;
    }
  }]);

  return DataPolygon;
}(React.Component);

DataPolygon.contextTypes = {
  mapContext: PropTypes.instanceOf(MapContext).isRequired
};

DataPolygon.defaultProps = {
  clickable: true
};

/* istanbul ignore else */
if (process.env.NODE_ENV !== "production") {
  DataPolygon.propTypes = {
    /**
     * Array of array of positions.
     */
    geometry: PropTypes.arrayOf(PropTypes.arrayOf(PropTypes.shape({
      /**
       * The latitude in degrees.
       */
      lat: PropTypes.number.isRequired,
      /**
       * The longitude in degrees.
       */
      lng: PropTypes.number.isRequired
    }))).isRequired,

    //
    // Style
    //

    /**
     * If true, the marker receives mouse and touch events.
     */
    clickable: PropTypes.bool,

    /**
     * The fill color.
     *
     * All CSS3 colors are supported except for extended named colors.
     */
    fillColor: PropTypes.string,

    /**
     * he fill opacity between 0.0 and 1.0.
     */
    fillOpacity: PropTypes.number,

    /**
     * The stroke color.
     *
     * All CSS3 colors are supported except for extended named colors.
     */
    strokeColor: PropTypes.string,

    /**
     * The stroke opacity between 0.0 and 1.0.
     */
    strokeOpacity: PropTypes.number,

    /**
     * The stroke width in pixels.
     */
    strokeWeight: PropTypes.number,

    /**
     * All features are displayed on the map in order of their zIndex,
     * with higher values displaying in front of features with lower values.
     */
    zIndex: PropTypes.number,

    //
    // Events
    //

    /**
     * This handler is called for a click on the geometry.
     */
    onClick: PropTypes.func,

    /**
     * This handler is called for a double click on the geometry.
     */
    onDoubleClick: PropTypes.func,

    /**
     * This handler is called for a right click on the geometry.
     */
    onRightClick: PropTypes.func,

    /**
     * This handler is called when the mouse leaves the area of the geometry.
     */
    onMouseOut: PropTypes.func,

    /**
     * This handler is called when the mouse enters the area of the geometry.
     */
    onMouseOver: PropTypes.func,

    /**
     * This handler is called for a mouse down on the geometry.
     */
    onMouseDown: PropTypes.func,

    /**
     * This handler is called for a mouse up on the geometry.
     */
    onMouseUp: PropTypes.func
  };
}

==> react-google-map-components-0.0.27.tgz: package/es/data-polygon/DataPolygon.js <==
import _isEqual from "lodash-es/isEqual";
import _pick from "lodash-es/pick";

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";

import PropTypes from "prop-types";
import { createListeners } from "../internal/Utils";
import { MapContext } from "../internal/MapContext";
import DataLayerEvents from "../data-layer/DataLayerEvents";

var pickStyles = function pickStyles(x) {
  return _pick(x, ["editable", "clickable", "draggable", "fillColor", "fillOpacity", "strokeColor", "strokeOpacity", "strokeWeight", "zIndex"]);
};

/**
 * Draws `google.maps.Data.Polygon`.
 *
 * **Usage:**
 *
 * ```javascript
 * import React from "react";
 * import { GoogleMap, DataPolygon } from "react-google-map-components"
 *
 * export default function GoogleMapWrapper(props) {
 *   return (
 *     <GoogleMap {...props} maps={google.maps}>
 *       <DataPolygon geometry={props.polygon} />
 *     </GoogleMap>
 *   );
 * }
 * ```
 *
 * **Google Maps Docs:**
 * * [google.maps.Data.Polygon](https://developers.google.com/maps/documentation/javascript/reference#Data.Polygon)
 */
export var DataPolygon = function (_React$Component) {
  _inherits(DataPolygon, _React$Component);

  function DataPolygon() {
    _classCallCheck(this, DataPolygon);

    return _possibleConstructorReturn(this, (DataPolygon.__proto__ || Object.getPrototypeOf(DataPolygon)).apply(this, arguments));
  }

  _createClass(DataPolygon, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      var _this2 = this;

      var mapContext = this.context.mapContext;


      this.listeners = [];
      this.feature = new mapContext.maps.Data.Feature();

      this.updateStyles();
      this.updateGeometry();

      mapContext.map.data.add(this.feature);

      createListeners(DataLayerEvents, function (x) {
        return _this2.props[x];
      }).forEach(function (_ref) {
        var _ref2 = _slicedToArray(_ref, 2),
            event = _ref2[0],
            listener = _ref2[1];

        _this2.addListener(event, listener);
      });
    }
  }, {
    key: "componentWillUpdate",
    value: function componentWillUpdate(nextProps) {
      this.updateStyles(nextProps);

      if (!_isEqual(nextProps.geometry, this.props.geometry)) {
        this.updateGeometry(nextProps);
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.context.mapContext.map.data.remove(this.feature);

      while (this.listeners.length > 0) {
        this.listeners.shift().remove();
      }
    }
  }, {
    key: "addListener",
    value: function addListener(event, listener) {
      var _this3 = this;

      this.listeners.push(this.context.mapContext.map.data.addListener(event, function (x) {
        if (x.feature === _this3.feature) {
          listener(x);
        }
      }));
    }
  }, {
    key: "updateStyles",
    value: function updateStyles() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;

      var styles = pickStyles(props);

      this.context.mapContext.map.data.overrideStyle(this.feature, styles);
    }
  }, {
    key: "updateGeometry",
    value: function updateGeometry() {
      var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.props;

      this.feature.setGeometry(new this.context.mapContext.maps.Data.Polygon(props.geometry));
    }
  }, {
    key: "render",
    value: function render() {
      return null;
    }
  }]);

  return DataPolygon;
}(React.Component);

DataPolygon.contextTypes = {
  mapContext: PropTypes.instanceOf(MapContext).isRequired
};

DataPolygon.defaultProps = {
  clickable: true
};

/* istanbul ignore else */
if (process.env.NODE_ENV !== "production") {
  DataPolygon.propTypes = {
    /**
     * Array of array of positions.
     */
    geometry: PropTypes.arrayOf(PropTypes.arrayOf(PropTypes.shape({
      /**
       * The latitude in degrees.
       */
      lat: PropTypes.number.isRequired,
      /**
       * The longitude in degrees.
       */
      lng: PropTypes.number.isRequired
    }))).isRequired,

    //
    // Style
    //

    /**
     * If true, the marker receives mouse and touch events.
     */
    clickable: PropTypes.bool,

    /**
     * If set to true, the user can drag this shape over the map. The geodesic property defines the mode of dragging.
     */
    draggable: PropTypes.bool,

    /**
     * If set to true, the user can edit this shape by dragging the control points shown at the vertices and on each segment.
     */
    editable: PropTypes.bool,

    /**
     * The fill color.
     *
     * All CSS3 colors are supported except for extended named colors.
     */
    fillColor: PropTypes.string,

    /**
     * he fill opacity between 0.0 and 1.0.
     */
    fillOpacity: PropTypes.number,

    /**
     * The stroke color.
     *
     * All CSS3 colors are supported except for extended named colors.
     */
    strokeColor: PropTypes.string,

    /**
     * The stroke opacity between 0.0 and 1.0.
     */
    strokeOpacity: PropTypes.number,

    /**
     * The stroke width in pixels.
     */
    strokeWeight: PropTypes.number,

    /**
     * All features are displayed on the map in order of their zIndex,
     * with higher values displaying in front of features with lower values.
     */
    zIndex: PropTypes.number,

    //
    // Events
    //

    /**
     * This handler is called for a click on the geometry.
     */
    onClick: PropTypes.func,

    /**
     * This handler is called for a double click on the geometry.
     */
    onDoubleClick: PropTypes.func,

    /**
     * This handler is called for a right click on the geometry.
     */
    onRightClick: PropTypes.func,

    /**
     * This handler is called when the mouse leaves the area of the geometry.
     */
    onMouseOut: PropTypes.func,

    /**
     * This handler is called when the mouse enters the area of the geometry.
     */
    onMouseOver: PropTypes.func,

    /**
     * This handler is called for a mouse down on the geometry.
     */
    onMouseDown: PropTypes.func,

    /**
     * This handler is called for a mouse up on the geometry.
     */
    onMouseUp: PropTypes.func
  };
}
